* Author: Antonio Soares Martins Neto 
* email: martinsneto.as@gmail.com or asmartins@worldbank.org
* Last updated: 29/11/2022
* Stata version: 17
/*=======================================================================*/

*===============================================================================
* THIS FILE: Define indexes
*===============================================================================

***************************** Management quality index ****************


*Firms ownership is a dummy equal to 1 whether the firm is not family-owned and 0 otherwise. Similarly, the use of formal incentives is a dummy equal to 1 if the firm adopts them. In contrast, the use of performance indicators is a variable with four different options: (1) no indicators;  (ii) 1 to 2 indicators; (iii) 3 to 9 indicators; and (iv) 10 or more indicators. To estimate the managerial quality index, we convert the latest to a variable varying from 0 to 1 and take the average of the three variables (ownership, incentives, and performance indicators).

*Ownership (variable a4b) (dummy equals to 0 if family company).
*Formal incentives (d4a) (dummy equals 1 if provides formal incentive)
*Number of performance indicators (index ranging from 0 to 10 or more indicators)

gen ownership = .
replace ownership = 0 if a4b == 1 | a4b == 2
replace ownership = 1 if a4b == 3

gen incentives = .
replace incentives = 0 if d4a == 2
replace incentives = 1 if d4a == 1

gen performance = d4b
replace performance = 0 if d4b == 4
replace performance  = (performance - 0)/(3-0)  

egen mq_index = rowmean(ownership incentives performance)

label var mq_index "Managerial quality index" 

***************************** Management human capital ****************

*We create an index based on managers' education, years of experience, experience in a large company, and whether the manager studied abroad. The first two variables are continuous, and we convert them into variables varying from 0 to 1. In the case of education, values include: 0 (primary school), 0.2 (secondary school), 0.4 (complete high-school), 0.6 (vocational training), 0.8 (college degree), and 1 (post-graduation). In the case of experience, we grouped the continuous variable into fivegroups: 0 (5 years or less), 0.25 (6 to 10 years), 0.5 (11 to 20 years), 0.75 (21 to 30 years), and 1 (more than 30 years). The last two variables are dummies equal 1 if the manager studied abroad and 1 if had experience in a large company. We take the average of the four variables to estimate the management human capital index.} 

*Education (variable a7c) (index ranging from 0 to 6 - post-graduation)
*Years of experience (variable a7a) (normalized to 1)
*CEO experience in a large company (variable d2e) (dummy equals to 1)
*Studied abroad (variable a7d) (dummy equals to 1)
/*
replace education = 0 if a7c == 1
replace education = 1 if a7c == 2
replace education = 2 if a7c == 3
replace education = 3 if a7c == 6
replace education = 4 if a7c == 4
replace education = 5 if a7c == 5


replace experience = 0 if a7a <= 5
replace experience = 1 if a7a > 5 & a5a <= 10
replace experience = 2 if a7a > 10 & a7a <= 20
replace experience = 3 if a7a > 20 & a7a <= 30
replace experience = 4 if a7a > 30

replace experience = experience/4
*/

gen education = 0
replace education = 1 if a7c == 4 | a7c == 5

gen experience = .
replace a7a = 2020 - a7a if a7a == 1991
replace a7a = 60 if a7a > 60 & a7a != .
egen max_experience = max(a7a)
egen min_experience = min(a7a)

replace experience = (a7a - min_experience)/(max_experience - min_experience)

gen experience_lc = .
replace experience_lc = 0 if d2e == 2
replace experience_lc = 1 if d2e == 1

gen studied_abroad = .
replace studied_abroad = 0 if a7d == 2 
replace studied_abroad = 1 if a7d == 1 

egen mhc_index = rowmean(education experience experience_lc studied_abroad)

label var mhc_index "Management human capital index" 

***************************** Capabilities ****************

*We develop an innovation and skills index by taking the share of college-educated employees, the share of workers exclusively dedicated to Research and Development activities, and whether the firm developed, customized, or significantly modified any equipment, machine, or software in the last three years. We convert the variables of the share of college and R\&D workers to variables ranging from 0 to 1 by dividing them by the maximum value in the sample. Following this conversion, we estimate the innovation and skills index by taking the average of the three variables (share of college-educated employees, share of R\&D workers, and innovation).

*Share of college-educated employees (variable e5d)
*R&D (variable e3h) (dummy equals to 1 if more than one employee dedicated)
*Develop, customize, or significantly modify any equipment, machine, or software? (variable d1c)

gen share_college = e5d/100
egen max_college = max(share_college)
replace share_college = share_college/max_college

replace e3h = e5h if e3h == . // Different variable for Bangladesh
gen R_and_D = .
replace R_and_D = e3h/tot_emp
replace R_and_D = . if R_and_D >= 0.9 // Clean cases in which the share of employees in R&D activities is too high
replace R_and_D = 0 if e3g == 2 // Replace to zero in case the firm doesn't have workers dedicated to R&D activities
egen max_RD = max(R_and_D) if R_and_D != . 
replace R_and_D  = R_and_D/max_RD  if R_and_D != . //Convert to value between 0 and 1 based on the max

gen develop = .
replace develop = 0 if d1c == 2
replace develop = 1 if d1c == 1

egen innovation_skills_index = rowmean(share_college R_and_D develop)

label var innovation_skills_index "Innovation and skills index"

********************************************************************

gen college_manager = 0
replace college_manager = 1 if a7c == 4 | a7c == 5
label var college_manager "Manager with college education"

**************************************************************************************************************************************************************************
************************************************************** Labels ************************************************************************************
**************************************************************************************************************************************************************************
label var ownership "Non-family Business"
label define ownership 0 "No" 1 "Yes", replace
label value ownership ownership

label var mnc_group "Multinational"
label define mnc_group 0 "No" 1 "Yes", replace
label value mnc_group mnc_group

label var exp_group "Exporter"
label define exp_group 0 "No" 1 "Yes", replace
label value exp_group exp_group

label var d2d "Interaction with MNEs"
label define d2d 0 "No" 1 "Yes", replace
label value d2d d2d

label var incentives "Formal incentives"
label define incentives 0 "No" 1 "Yes", replace
label value incentives incentives

label var experience_lc "Experience in large company"
label define experience_lc 0 "No" 1 "Yes", replace
label value experience_lc experience_lc

label var studied_abroad "Manager studied abroad"
label define studied_abroad  0 "No" 1 "Yes", replace
label value studied_abroad  studied_abroad 

label var develop "Innovation"
label define develop  0 "No" 1 "Yes", replace
label value develop  develop

label var college_manager "Manager's with college"
label define college_manager  0 "No" 1 "Yes", replace
label value college_manager college_manager


label var education "Manager's education"
label var experience "Manager's years of experience"
label var performance "Performance indicators"
label var college_manager "Manager's with college"
label var a7a "Manager's experience (years)"

label var tech_max_gbf_firm "GBFs - Extensive margin"
label var tech_max_sbf_firm "SBFs - Extensive margin"
label var tech_int_gbf_firm "GBFs - Intensive margin"
label var tech_int_sbf_firm "SBFs - Intensive margin"
label var tot_emp "Number of employees"

label var e5d "Share of workers with college education"
label var share_college "Share of college-educated employees"
label var R_and_D "Share of R\&D employees"

